/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package ai

import (
	"context"
	"github.com/jinzhu/copier"
	"github.com/pkg/errors"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/helper/xerr"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"gitlink.org.cn/jcce-pcm/pcm-participant-modelarts/modelarts"

	"github.com/zeromicro/go-zero/core/logx"
)

type CreateProcessorTaskLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewCreateProcessorTaskLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CreateProcessorTaskLogic {
	return &CreateProcessorTaskLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *CreateProcessorTaskLogic) CreateProcessorTask(req *types.CreateProcessorTaskReq) (resp *types.CreateProcessorTaskResp, err error) {
	modelartsReq := &modelarts.CreateProcessorTaskReq{}
	err = copier.CopyWithOption(modelartsReq, req, copier.Option{Converters: utils.Converters})
	CreateProcessorTaskResp, err := l.svcCtx.ModelArtsRpc.CreateProcessorTask(l.ctx, modelartsReq)
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrMsg("Failed to get db DataSet list"), "Failed to get db DataSet list err : %v ,req:%+v", err, req)
	}
	resp = &types.CreateProcessorTaskResp{}

	err = copier.CopyWithOption(&resp, &CreateProcessorTaskResp, copier.Option{Converters: utils.Converters})

	return resp, nil
}
