/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package ai

import (
	"context"
	"github.com/jinzhu/copier"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	error2 "gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/repository/error"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"gitlink.org.cn/jcce-pcm/pcm-participant-modelarts/modelarts"
	"k8s.io/apimachinery/pkg/util/json"

	"github.com/zeromicro/go-zero/core/logx"
)

type DeleteTrainingJobLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewDeleteTrainingJobLogic(ctx context.Context, svcCtx *svc.ServiceContext) *DeleteTrainingJobLogic {
	return &DeleteTrainingJobLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *DeleteTrainingJobLogic) DeleteTrainingJob(req *types.DeleteTrainingJobReq) (resp *types.DeleteTrainingJobResp, err error) {
	modelartsReq := &modelarts.DeleteTrainingJobReq{}
	err = copier.CopyWithOption(modelartsReq, req, copier.Option{Converters: utils.Converters})
	deleteTrainingJobResp, err := l.svcCtx.ModelArtsRpc.DeleteTrainingJob(l.ctx, modelartsReq)
	if err != nil {
		return nil, error2.NewDefaultError(err.Error())
	}
	marshal, err := json.Marshal(&deleteTrainingJobResp)
	if err != nil {
		return nil, error2.NewDefaultError(err.Error())
	}
	json.Unmarshal(marshal, &resp)
	err = copier.CopyWithOption(&resp, &deleteTrainingJobResp, copier.Option{Converters: utils.Converters})
	return resp, nil
}
