/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package ai

import (
	"context"
	"github.com/jinzhu/copier"
	"github.com/pkg/errors"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/helper/xerr"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/repository/result"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"gitlink.org.cn/jcce-pcm/pcm-participant-modelarts/modelarts"
	"k8s.io/apimachinery/pkg/util/json"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetListTrainingJobsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetListTrainingJobsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetListTrainingJobsLogic {
	return &GetListTrainingJobsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetListTrainingJobsLogic) GetListTrainingJobs(req *types.ListTrainingJobsreq) (resp *types.ListTrainingJobsresp, err error) {
	modelartsReq := &modelarts.ListTrainingJobsreq{}
	err = copier.CopyWithOption(modelartsReq, req, copier.Option{Converters: utils.Converters})
	listDataSetResp, err := l.svcCtx.ModelArtsRpc.GetListTrainingJobs(l.ctx, modelartsReq)
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrMsg("Failed to get db DataSet list"), "Failed to get db DataSet list err : %v ,req:%+v", err, req)
	}
	marshal, err := json.Marshal(&listDataSetResp)
	if err != nil {
		return nil, result.NewDefaultError(err.Error())
	}
	json.Unmarshal(marshal, &resp)
	err = copier.CopyWithOption(&resp, &listDataSetResp, copier.Option{Converters: utils.Converters})
	return resp, nil
	/*	modelartsType := req.ModelartsType
		switch modelartsType {
		case "octops":
			octopusReq := &octopus.GetTrainJobListReq{}
			err = copier.CopyWithOption(octopusReq, req, copier.Option{Converters: utils.Converters})
			listTrainJobResp, err := l.svcCtx.OctopusRpc.GetTrainJobList(l.ctx, octopusReq)
			if err != nil {
				return nil, errors.Wrapf(xerr.NewErrMsg("Failed to get db TrainJobs list"), "Failed to get db DataSet list err : %v ,req:%+v", err, req)
			}
			marshal, err := json.Marshal(&listTrainJobResp)
			if err != nil {
				return nil, result.NewDefaultError(err.Error())
			}
			json.Unmarshal(marshal, &resp)
			err = copier.CopyWithOption(&resp, &listTrainJobResp, copier.Option{Converters: utils.Converters})
		case "cn-north-4.myhuawei":
			modelartsReq := &modelarts.ListTrainingJobsreq{}
			err = copier.CopyWithOption(modelartsReq, req, copier.Option{Converters: utils.Converters})
			listDataSetResp, err := l.svcCtx.ModelArtsRpc.GetListTrainingJobs(l.ctx, modelartsReq)
			if err != nil {
				return nil, errors.Wrapf(xerr.NewErrMsg("Failed to get db TrainJobs list"), "Failed to get db DataSet list err : %v ,req:%+v", err, req)
			}
			marshal, err := json.Marshal(&listDataSetResp)
			if err != nil {
				return nil, result.NewDefaultError(err.Error())
			}
			json.Unmarshal(marshal, &resp)
			err = copier.CopyWithOption(&resp, &listDataSetResp, copier.Option{Converters: utils.Converters})
		case "cn-east-293.njaci":
			modelartsReq := &modelarts.ListTrainingJobsreq{}

			err = copier.CopyWithOption(modelartsReq, req, copier.Option{Converters: utils.Converters})
			listDataSetResp, err := l.svcCtx.ModelArtsRpc.GetListTrainingJobs(l.ctx, modelartsReq)
			if err != nil {
				return nil, errors.Wrapf(xerr.NewErrMsg("Failed to get db TrainJobs list"), "Failed to get db DataSet list err : %v ,req:%+v", err, req)
			}
			marshal, err := json.Marshal(&listDataSetResp)
			if err != nil {
				return nil, result.NewDefaultError(err.Error())
			}
			json.Unmarshal(marshal, &resp)
			err = copier.CopyWithOption(&resp, &listDataSetResp, copier.Option{Converters: utils.Converters})
		}*/

}
