package core

import (
	"context"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/pkg/response"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/constants"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/models"
	tool "gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"k8s.io/apimachinery/pkg/util/json"
	"time"

	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type CommitHpcTaskLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewCommitHpcTaskLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CommitHpcTaskLogic {
	return &CommitHpcTaskLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *CommitHpcTaskLogic) CommitHpcTask(req *types.CommitHpcTaskReq) (resp *types.CommitHpcTaskResp, err error) {
	// 构建主任务结构体
	taskModel := models.Task{
		Status:      constants.Saved,
		Description: req.Description,
		Name:        req.Name,
		CommitTime:  time.Now(),
	}
	// 保存任务数据到数据库
	tx := l.svcCtx.DbEngin.Create(&taskModel)
	if tx.Error != nil {
		return nil, tx.Error
	}
	hpc := models.Hpc{}
	tool.Convert(req, &hpc)
	mqInfo := response.TaskInfo{
		TaskId:      taskModel.Id,
		TaskType:    "hpc",
		MatchLabels: req.MatchLabels,
		//Metadata:    hpc,
	}
	req.TaskId = taskModel.Id
	// 将任务数据转换成消息体
	reqMessage, err := json.Marshal(mqInfo)
	if err != nil {
		logx.Error(err)
		return nil, err
	}
	publish := l.svcCtx.RedisClient.Publish(context.Background(), mqInfo.TaskType, reqMessage)
	if publish.Err() != nil {
		return nil, publish.Err()
	}
	return
}
