/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package core

import (
	"context"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/models"

	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetRegionLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetRegionLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetRegionLogic {
	return &GetRegionLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetRegionLogic) GetRegion() (resp *types.GetRegionResp, err error) {
	resp = &types.GetRegionResp{}
	var regionSlurmArray []models.RegionSlurm
	regionNameDb := l.svcCtx.DbEngin.Find(&regionSlurmArray).Not("RegionName = ?", "")
	softStackDb := l.svcCtx.DbEngin.Find(&regionSlurmArray).Not("SoftStack = ?", "")
	resp = &types.GetRegionResp{
		Code: 200,
		Msg:  "Success",
		Data: types.RegionNum{
			RegionSum:    regionNameDb.RowsAffected,
			SoftStackSum: softStackDb.RowsAffected,
		},
	}
	return resp, err
}
