/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package core

import (
	"context"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type NodeAssetsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewNodeAssetsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *NodeAssetsLogic {
	return &NodeAssetsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *NodeAssetsLogic) NodeAssets() (resp *types.NodeAssetsResp, err error) {
	// 查询数据库系节点动态资源信息

	nodeResp := types.NodeAssetsResp{}
	tx := l.svcCtx.DbEngin.Raw("SELECT ppi.`name`,nai.* FROM sc_node_avail_info nai left join sc_participant_phy_info ppi on ppi.id = nai.participant_id  WHERE nai.id IN ( SELECT MAX( id )  FROM sc_node_avail_info WHERE deleted_flag = 0 GROUP BY participant_id, node_name) ").Scan(&nodeResp.NodeAssets)
	if tx.Error != nil {
		logx.Error(err)
		return nil, tx.Error
	}
	return &nodeResp, nil
}
