/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package core

import (
	"context"
	"github.com/zeromicro/go-zero/core/logx"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/models"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"time"
)

type PutResourcePanelConfigLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewPutResourcePanelConfigLogic(ctx context.Context, svcCtx *svc.ServiceContext) *PutResourcePanelConfigLogic {
	return &PutResourcePanelConfigLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *PutResourcePanelConfigLogic) PutResourcePanelConfig(req *types.ResourcePanelConfigReq) error {
	rpcModel := models.ResourcePanelConfig{}
	utils.Convert(req, &rpcModel)
	rpcModel.UpdateTime = time.Now()

	update := l.svcCtx.DbEngin.Model(&rpcModel).Updates(rpcModel)
	err := update.Error
	if err != nil {
		logx.WithContext(l.ctx).Errorf("PCM 资源面板数据更新失败 err: %s", err.Error())
		return err
	}
	return nil
}
