/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package core

import (
	"context"
	"github.com/jinzhu/copier"
	"github.com/pkg/errors"
	"gitlink.org.cn/jcce-pcm/pcm-ac/hpcAC"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/helper/xerr"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"gitlink.org.cn/jcce-pcm/pcm-slurm/slurmclient"
	"strconv"

	"github.com/zeromicro/go-zero/core/logx"
)

type SubmitJobLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSubmitJobLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SubmitJobLogic {
	return &SubmitJobLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *SubmitJobLogic) SubmitJob(req *types.SubmitJobReq) (resp *types.SubmitJobResp, err error) {

	coreResp := &types.SubmitJobResp{}

	version := req.SlurmVersion
	switch version {
	case "ac":
		acReq := &hpcAC.SubmitJobReq{}
		err = copier.CopyWithOption(acReq, req, copier.Option{Converters: utils.Converters})
		acResp, err := l.svcCtx.ACRpc.SubmitJob(l.ctx, acReq)

		if err != nil {
			return nil, errors.Wrapf(xerr.NewErrMsg("Failed to submit job to AC"), "Failed to submit job to Shuguang err : %v ,req:%+v", err, req)
		}

		if acResp.Data == "" {
			return nil, errors.Wrapf(xerr.NewErrMsg("Failed to submit job to AC, job id is empty"), "Failed to submit job to Shuguang err : %v", err)
		}

		coreResp.Msg = acResp.Msg
		coreResp.Code = acResp.Code
		coreResp.Data = acResp.Data

	case "th":
		thReq := &slurmclient.SubmitJobReq{}
		err = copier.CopyWithOption(thReq, req, copier.Option{Converters: utils.Converters})
		tianheResp, err := l.svcCtx.THRpc.SubmitJob(l.ctx, thReq)

		if err != nil {
			return nil, errors.Wrapf(xerr.NewErrMsg("Failed to submit job to Tianhe"), "Failed to submit job to Tianhe err : %v ,req:%+v", err, req)
		}

		coreResp.Msg = "success"
		coreResp.Code = strconv.Itoa(200)
		coreResp.Data = strconv.Itoa(int(tianheResp.JobId))
	}

	return coreResp, nil
}
