/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package storage

import (
	"context"
	"github.com/jinzhu/copier"
	"github.com/pkg/errors"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/helper/xerr"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/repository/result"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"gitlink.org.cn/jcce-pcm/pcm-participant-ceph/ceph"
	"k8s.io/apimachinery/pkg/util/json"

	"github.com/zeromicro/go-zero/core/logx"
)

type ScreenStorageLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewScreenStorageLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ScreenStorageLogic {
	return &ScreenStorageLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *ScreenStorageLogic) ScreenStorage(req *types.StorageScreenReq) (resp *types.StorageScreenResp, err error) {
	// todo: add your logic here and delete this line
	storageScreenReq := &ceph.StorageScreenReq{}
	err = copier.CopyWithOption(storageScreenReq, req, copier.Option{Converters: utils.Converters})
	StorageScreenResp, err := l.svcCtx.CephRpc.StorageScreen(l.ctx, storageScreenReq)
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrMsg("Failed to get db storage list"), "Failed to get db storage list err : %v ,req:%+v", err, req)
	}
	marshal, err := json.Marshal(&StorageScreenResp)
	if err != nil {
		return nil, result.NewDefaultError(err.Error())
	}
	json.Unmarshal(marshal, &resp)
	err = copier.CopyWithOption(&resp, &StorageScreenResp, copier.Option{Converters: utils.Converters})
	return resp, nil
}
