/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package storelink

import (
	"context"
	"github.com/zeromicro/go-zero/core/logx"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/storeLink"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/models"
)

type GetLinkImageListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetLinkImageListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetLinkImageListLogic {
	return &GetLinkImageListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetLinkImageListLogic) GetLinkImageList(req *types.GetLinkImageListReq) (resp *types.GetLinkImageListResp, err error) {
	participant := storeLink.GetParticipantById(req.PartId, l.svcCtx.DbEngin)
	if *participant == (models.StorelinkCenter{}) {
		resp = &types.GetLinkImageListResp{}
		resp.Success = false
		resp.Images = nil
		resp.ErrorMsg = "partId不存在"
		return resp, nil
	}

	storelink := storeLink.NewStoreLink(l.ctx, l.svcCtx, participant)
	if storelink == nil {
		return nil, nil
	}

	list, err := storelink.ILinkage.QueryImageList()
	if err != nil {
		return nil, err
	}
	if list == nil {
		return nil, nil
	}

	listResp := list.(types.GetLinkImageListResp)
	return &listResp, nil
}
