/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package storelink

import (
	"context"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/storeLink"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/models"

	"github.com/zeromicro/go-zero/core/logx"
)

type SubmitLinkTaskLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSubmitLinkTaskLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SubmitLinkTaskLogic {
	return &SubmitLinkTaskLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *SubmitLinkTaskLogic) SubmitLinkTask(req *types.SubmitLinkTaskReq) (resp *types.SubmitLinkTaskResp, err error) {
	participant := storeLink.GetParticipantById(req.PartId, l.svcCtx.DbEngin)
	if *participant == (models.StorelinkCenter{}) {
		resp = &types.SubmitLinkTaskResp{}
		resp.Success = false
		resp.TaskId = ""
		resp.ErrorMsg = "partId不存在"
		return resp, nil
	}

	storelink := storeLink.NewStoreLink(l.ctx, l.svcCtx, participant)
	if storelink == nil {
		return nil, nil
	}

	var params []string
	if len(req.Params) != 0 {
		for _, v := range req.Params {
			param := v.Key + storeLink.COMMA + v.Val
			params = append(params, param)
		}
	}
	var envs []string
	if len(req.Envs) != 0 {
		for _, v := range req.Envs {
			env := v.Key + storeLink.COMMA + v.Val
			envs = append(envs, env)
		}
	}
	task, err := storelink.ILinkage.SubmitTask(req.ImageId, req.Cmd, envs, params, req.ResourceId)
	if err != nil {
		return nil, err
	}

	taskResp := task.(types.SubmitLinkTaskResp)
	return &taskResp, nil
}
