/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package vm

import (
	"context"
	"github.com/jinzhu/copier"
	"github.com/pkg/errors"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/helper/xerr"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/repository/result"
	tool "gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/utils"
	"gitlink.org.cn/jcce-pcm/pcm-participant-openstack/openstack"
	"k8s.io/apimachinery/pkg/util/json"

	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetServersDetailedByIdLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetServersDetailedByIdLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetServersDetailedByIdLogic {
	return &GetServersDetailedByIdLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetServersDetailedByIdLogic) GetServersDetailedById(req *types.GetServersDetailedByIdReq) (resp *types.GetServersDetailedByIdResp, err error) {
	// todo: add your logic here and delete this line
	GetServersDetailedByIdReq := &openstack.GetServersDetailedByIdReq{}
	err = copier.CopyWithOption(GetServersDetailedByIdReq, req, copier.Option{Converters: tool.Converters})
	GetServersDetailedByIdResp, err := l.svcCtx.OpenstackRpc.GetServersDetailedById(l.ctx, GetServersDetailedByIdReq)
	if err != nil {
		return nil, errors.Wrapf(xerr.NewErrMsg("Failed to get Servers list"), "Failed to get db Servers list err : %v ,req:%+v", err, req)
	}
	marshal, err := json.Marshal(&GetServersDetailedByIdResp)
	if err != nil {
		return nil, result.NewDefaultError(err.Error())
	}
	json.Unmarshal(marshal, &resp)
	err = copier.CopyWithOption(&resp, &GetServersDetailedByIdResp, copier.Option{Converters: tool.Converters})
	return resp, err
}
