/*

 Copyright (c) [2023] [pcm]
 [pcm-coordinator] is licensed under Mulan PSL v2.
 You can use this software according to the terms and conditions of the Mulan PSL v2.
 You may obtain a copy of Mulan PSL v2 at:
          http://license.coscl.org.cn/MulanPSL2
 THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 EITHER EXPaRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 See the Mulan PSL v2 for more details.

*/

package mqs

import (
	"context"
	"gitlink.org.cn/jcce-pcm/pcm-coordinator/api/internal/svc"
	scheduler2 "gitlink.org.cn/jcce-pcm/pcm-coordinator/pkg/scheduler"
)

/*
*
Listening to the payment flow status change notification message queue
*/
type HpcMq struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewHpcMq(ctx context.Context, svcCtx *svc.ServiceContext) *HpcMq {
	return &HpcMq{
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *HpcMq) Consume(val string) error {
	// 接受消息, 根据标签筛选过滤
	hpcSchdl := scheduler2.NewHpcScheduler(val)
	schdl, err := scheduler2.NewScheduler(hpcSchdl, val, l.svcCtx.DbEngin, nil)
	if err != nil {
		return err
	}
	schdl.MatchLabels()

	// 调度算法
	err = schdl.AssignAndSchedule()
	if err != nil {
		return err
	}

	// 存储数据
	err = schdl.SaveToDb()
	if err != nil {
		return err
	}
	return nil
}
